==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_Module.h <==
//----------------------------------------------------------------------------
// wxModule
// extracted from module.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_MODULE_H__
#define __CLASS_WX_MODULE_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxModule
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_Module);

//----------------------------------------------------------------------------
// Object declaration for wxModule
//----------------------------------------------------------------------------
class Object_wx_Module : public Object_wx_Object {
public:
	Gura_DeclareObjectAccessor(wx_Module)
public:
	inline Object_wx_Module(wxModule *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(Gura_UserClass(wx_Module), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_Module(Class *pClass, wxModule *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_Module();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxModule *GetEntity() {
		return dynamic_cast<wxModule *>(_pEntity);
	}
	inline wxModule *ReleaseEntity() {
		wxModule *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxModule");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_Module.h <==
//----------------------------------------------------------------------------
// wxModule
// extracted from module.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_MODULE_H__
#define __CLASS_WX_MODULE_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxModule
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_Module);

//----------------------------------------------------------------------------
// Object declaration for wxModule
//----------------------------------------------------------------------------
class Object_wx_Module : public Object_wx_Object {
public:
	Gura_DeclareObjectAccessor(wx_Module)
public:
	inline Object_wx_Module(wxModule *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(Gura_UserClass(wx_Module), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_Module(Class *pClass, wxModule *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_Module();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxModule *GetEntity() {
		return dynamic_cast<wxModule *>(_pEntity);
	}
	inline wxModule *ReleaseEntity() {
		wxModule *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxModule");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
